#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre-installation file for owswitch services on EIS/FAIR
#
# Copyright (c) 2016-2016 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:    2016-06-13 jed
# Last Update: $Id: preinstall.sh 44081 2016-12-09 14:29:40Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib

# file names and pathes
module_name='owswitch'

mecho --info "running preinstall.sh ..."

installfile=/var/run/${module_name}.install
configfile=/etc/config.d/${module_name}
deinstallfile=/var/install/deinstall/${module_name}
packagefile=/var/install/packages/${module_name}

# check base version
if [ -f ${packagefile} ]
then
    base_version="`grep "<require-package>base " ${packagefile} | sed 's#^.*<require-package>base *\(.*\) *</require-.*$#\1#'`"
else
    base_version='2.7.8'
fi

installed_version=`/var/install/bin/check-version base ${base_version}`

case ${installed_version} in
    not-installed|new ) # wrong version
        mecho --warn "required base package v${base_version} or newer not installed - installation aborted."
        /var/install/bin/anykey
        exit 1
        ;;
    * ) # installed / old
        ;;
esac

# backup existing file
if [ -f ${configfile} ]
then
    # move old files to backup directory and create backup
    /var/install/bin/backup-file --quiet ${module_name}

    mecho "saving previous configuration file to ${installfile} ..."
    cp ${configfile} ${installfile}
fi

# deinstall old software
mecho "deinstalling previously installed software ..."
/var/install/bin/del-package -p ${module_name} --update

exit 0
