#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/owswitch-update.sh - update script
#
# Copyright (c) 2016-2016 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:    2016-06-13 jed
# Last Update: $Id: owswitch-update.sh 41911 2016-06-14 21:38:05Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib
. /var/install/include/configlib
. /var/install/include/jedlib
. /var/install/include/check-eisfair-version

# activate debug output
debug_print=true
#debug_trace=true
if ${debug_trace:-false}
then
    exec 2> /tmp/$(basename ${0})-trace-$$.log
    set -x
    ask_debug=true
    export ask_debug
    debug_print=true
fi

#------------------------------------------------------------------------------
# function: variable is set
#
# input:  $1 - variable name
# return:  0 - variable set
#          1 - variable not set
#------------------------------------------------------------------------------
variable_set ()
{
    eval _var1=\$"${1}"
    eval _var2=\$"{${1}+EMPTY}"

    if [ -z "${_var1}" ]
    then
        if [ "${_var2}" = "EMPTY" ]
        then
            # variable is empty, but set
            ret=0
        else
            # variable is not set
            ret=1
        fi
    else
        # variable has a value
        ret=0
    fi

    return ${ret}
}

#------------------------------------------------------------------------------
# print variable only if it has been set
# $1 - variable name
# $2 - comment
#------------------------------------------------------------------------------
printsetvar ()
{
    if variable_set "${1}"
    then
        printvar "${1}" "${2}"
    fi
}

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    renamed=0
    mecho "renaming parameter(s) ..."

    if [ ${renamed} -eq 1 ]
    then
        mecho --info "... read documentation for renamed parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    modified=0
    mecho "modifying parameter(s) ..."

    if [ ${modified} -eq 1 ]
    then
        mecho --info "... read documentation for modified parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    added=0
    mecho "adding new parameter(s) ..."

    if [ ${added} -eq 1 ]
    then
        mecho --info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    deleted=0
    mecho "deleting old parameters ..."

    if [ ${deleted} -eq 1 ]
    then
        anykey
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "owswitch" "2016-06-07" "jed"
        #------------------------------------------------------------------------------

        if [ "${OWSWITCH_DO_DEBUG}" = "yes" -o "${OWSWITCH_DO_DEBUG}" = "no" ]
        then
            # debug active
            printvar "OWSWITCH_DO_DEBUG" "debug mode: yes or no"
            echo
        else
            # debug parameter exists but not active
            if [ -n "`grep OWSWITCH_DO_DEBUG ${source_conf}`" ]
            then
                echo "# OWSWITCH_DO_DEBUG='yes'                  # debug mode: yes or no"
                echo
            fi
        fi

        #------------------------------------------------------------------------------
        printgroup "general configuration"
        #------------------------------------------------------------------------------
        printvar    "START_OWSWITCH"               "activate configuration: yes or no"
        echo
        printsetvar "OWSWITCH_SOURCE"              "source: owread or owhttp"
        printsetvar "OWSWITCH_OWFS_HOSTNAME"       "host name"
        printsetvar "OWSWITCH_OWFS_PORT"           "host port"

        printvar    "OWSWITCH_N"                   "number of sensors"

        if [ "${OWSWITCH_N}" -eq '0' ]
        then
            imax=1
        else
            imax=${OWSWITCH_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            printvar "OWSWITCH_${idx}_ID"     "${idx}. sensor ID"
            printvar "OWSWITCH_${idx}_NAME"   "   name of sensor"
            printvar "OWSWITCH_${idx}_ACTIVE" "   activate sensor: yes or no"
            echo
            printvar "OWSWITCH_${idx}_PIO_N"  "   number of pio ports"

            eval pio_n='$OWSWITCH_'${idx}'_PIO_N'

            if [ "${pio_n}" -eq '0' ]
            then
                jmax=1
            else
                jmax=${pio_n}
            fi

            jdx=1
            while [ ${jdx} -le ${jmax} ]
            do
                printvar "OWSWITCH_${idx}_PIO_${jdx}_NAME"            "   ${jdx}. name of pio port"
                printvar "OWSWITCH_${idx}_PIO_${jdx}_FUNC"            "      pio function: input, output or none"
                printvar "OWSWITCH_${idx}_PIO_${jdx}_INPUT_DEFAULT"   "      pio input default: 0-close, 1-open"
                printvar "OWSWITCH_${idx}_PIO_${jdx}_ON_EXEC_ACTIVE"  "      activate on-command"
                printvar "OWSWITCH_${idx}_PIO_${jdx}_ON_EXEC"         "      command to execute on activation"
                printvar "OWSWITCH_${idx}_PIO_${jdx}_OFF_EXEC_ACTIVE" "      activate off-command"
                printvar "OWSWITCH_${idx}_PIO_${jdx}_OFF_EXEC"        "      command to execute off activation"

                jdx=`expr ${jdx} + 1`
            done

            idx=`expr ${idx} + 1`
        done

        #------------------------------------------------------------------------------
        printend
        #------------------------------------------------------------------------------
    } > ${generate_conf}

    anykey
}

#==============================================================================
# main
#==============================================================================

configfile=/etc/config.d/owswitch
installfile=/var/run/owswitch.install

# setting defaults
source_conf=${installfile}
generate_conf=${configfile}

goflag=0

case "$1" in
    update )
        goflag=1
        ;;

    test )
        source_conf=${configfile}
      # source_conf=${configfile}.new

        generate_conf=/etc/config.d/owswitch.test
        goflag=1
        ;;
    * )
        mecho
        mecho "Use one of the following options:"
        mecho
        mecho "  owswitch-update.sh [update] - the file ${configfile}.import will be read, the configuration will"
        mecho "                                be checked and an updated mail configuration file will be written."
        mecho
        goflag=0
        ;;
esac

if [ ${goflag} -eq 1 ]
then
    if [ -f ${source_conf} ]
    then
        # previous configuration file exists
        mecho --info "previous configuration found ..."
        . ${source_conf}

        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else
        mecho --error "no configuration ${source_conf} found - exiting."
        anykey
    fi
fi

#==============================================================================
# End
#==============================================================================
exit 0
