#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/dialog.d/OWSWITCH_SENSOR_ID.sh
#
# Copyright (c) 2016-2016 the Eisfair team, team(at)eisfair(dot)org>
#
# Creation:     2016-06-13 jed
# Last Update:  $Id: OWSWITCH_SENSOR_ID.sh 43674 2016-10-14 13:35:02Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

. /var/install/include/cuilib
. /var/install/include/ecelib

#exec 2>/tmp/OWSWITCH_SENSOR_ID-trace-$$.log
#set -x

module_name='owswitch'
configfile=/etc/config.d/${module_name}

#----------------------------------------------------------------------------
# check if sensor has already been configured
#----------------------------------------------------------------------------
sensor_configured()
{
    local _sc_sensorid="`echo "$1" | sed 's/^\(..\)\(.*\)..$/\1.\2/'`"
    local _sc_ow_n='0'
    local _sc_ow_active='no'
    local _sc_ow_id=''

    ece_get_value ${win} OWSWITCH_N && _sc_ow_n=${p2}

    _sc_out=''
    _sc_idx=1
    while [ ${_sc_idx} -le ${_sc_ow_n} ]
    do
        ece_get_value ${win} OWSWITCH_${_sc_idx}_ACTIVE && _sc_ow_active=${p2}
        ece_get_value ${win} OWSWITCH_${_sc_idx}_ID && _sc_ow_id=${p2}

        if [ "${_sc_sensorid}" = "${_sc_ow_id}" ]
        then
            if [ "${_sc_ow_active}" = 'no' ]
            then
                _sc_out="${_sc_idx} (inactive)"
            else
                _sc_out="${_sc_idx} (active)"
            fi

            break
        fi

        _sc_idx=`expr ${_sc_idx} + 1`
    done

    echo "${_sc_out}"
}

#----------------------------------------------------------------------------
# exec_dailog
# ece --> request to create and execute dialog
#         $p2 --> main window handle
#         $p3 --> name of config variable
#----------------------------------------------------------------------------
exec_dialog()
{
    local win="${p2}"
    local esource
    local varname="${p3}"
    local varidx=`echo "${varname}" | sed 's/^OWSWITCH_\([0-9]*\)_.*$/\1/'`

    ece_get_value ${win} OWSWITCH_SOURCE && esource=${p2}

    if [ -z "${esource}" ]
    then
        # set default source
        esource='owread'
    fi

    sellist=''
    case ${esource} in
        owhttp )
            # remote
            ece_get_value ${win} OWSWITCH_OWFS_HOSTNAME && hostname=${p2}
            ece_get_value ${win} OWSWITCH_OWFS_PORT && port=${p2}

            if [ "${hostname}" = '' ]
            then
                hostname="`hostname --fqdn`"
            fi

            if [ -z "${port}" ]
            then
                port='2121'
            fi

            # read list of sensors (without aliased sensors)
            sensors=`wget.sh -qO- ${hostname}:${port} | sed 's#<TR>#\n<TR>#g' | grep '<TD>directory</TD>' | \
                     sed -e 's#</TR>.*$##g' -e "s/^.*HREF='\([^']*\).*<BIG>.*$/\1:/g" -e 's#^/##' | grep '^3A' | tr -d ':'`

            # read list of aliased sensors
            aliasedsensors=`wget.sh -qO- farragut:2121/settings/alias/list | sed -e 's/^.*<TD>\([^<]*\).*$/\1/' | \
                            grep '^3A' | sed 's/=.*$//g' | sed 's/^\(..\)\(.*\)..$/\1.\2/'`

            # add aliased sensors to list
            for ALIAS in ${aliasedsensors}
            do
                echo "${sensors}" | grep -q "^${ALIAS}"

                if [ $? -ne 0 ]
                then
                    sensors="${sensors}
${ALIAS}"
                fi
            done
            ;;
        owread )
            # local
            eval `grep "OWFS_SERVER_OWFS_MOUNT" /etc/config.d/owfs`

            for SENSORADDR in `find ${OWFS_SERVER_OWFS_MOUNT} -maxdepth 2 -name "address" | sed "s#^${OWFS_SERVER_OWFS_MOUNT}/##"`
            do
                # '3A698402010800A0' -> '3A.698402010800'
                sensorid=`owread ${SENSORADDR} | grep "^3A"`

                if [ ! -z "${sensorid}" ]
                then
                    sensor_idx=`sensor_configured "${sensorid}"`

                    if [ "${sensors}" = '' ]
                    then
                        sensors="`echo "${sensorid}" | sed 's/^\(..\)\(.*\)..$/\1.\2/'`|${sensor_idx}"
                    else
                        sensors="${sensors}
`echo "${sensorid}" | sed 's/^\(..\)\(.*\)..$/\1.\2/'`|${sensor_idx}"
                    fi
                fi
            done
            ;;
    esac

    # format selection list
    sellist=",`echo "${sensors}" | sort | tr '\n' ',' | sed 's/,$//'`"

    ece_comment_list_dlg "${win}" "Sensor ID" "${sellist}"
}

#----------------------------------------------------------------------------
# main routine
#----------------------------------------------------------------------------

cui_init
cui_run

#----------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------
exit 0
